# Table of Contents

- [exporting-workspace-snapshots](<./exporting-workspace-snapshots.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Exporting Workspace Snapshots](<./Exporting-Workspace-Snapshots.md>)
  - [Overview](<./Exporting-Workspace-Snapshots/Overview.md>)
  - [Prerequisites](<./Exporting-Workspace-Snapshots/Prerequisites.md>)
  - [Step 1: Initiate an Export Job](<./Exporting-Workspace-Snapshots/Step-1-Initiate-an-Export-Job.md>)
  - [Step 2: Retrieve a One-Time Download Key](<./Exporting-Workspace-Snapshots/Step-2-Retrieve-a-One-Time-Download-Key.md>)
  - [Step 3: Retrieve a File with Workspace Data](<./Exporting-Workspace-Snapshots/Step-3-Retrieve-a-File-with-Workspace-Data.md>)
  - [Next Steps](<./Exporting-Workspace-Snapshots/Next-Steps.md>)
